pub enum VertexAttributeValues {
Show 45 variants
Uint8(Vec<u8>),
Uint8x2(Vec<[u8; 2]>),
Uint8x4(Vec<[u8; 4]>),
Sint8(Vec<i8>),
Sint8x2(Vec<[i8; 2]>),
Sint8x4(Vec<[i8; 4]>),
Unorm8(Vec<u8>),
Unorm8x2(Vec<[u8; 2]>),
Unorm8x4(Vec<[u8; 4]>),
Snorm8(Vec<i8>),
Snorm8x2(Vec<[i8; 2]>),
Snorm8x4(Vec<[i8; 4]>),
Uint16(Vec<u16>),
Uint16x2(Vec<[u16; 2]>),
Uint16x4(Vec<[u16; 4]>),
Sint16(Vec<i16>),
Sint16x2(Vec<[i16; 2]>),
Sint16x4(Vec<[i16; 4]>),
Unorm16(Vec<u16>),
Unorm16x2(Vec<[u16; 2]>),
Unorm16x4(Vec<[u16; 4]>),
Snorm16(Vec<i16>),
Snorm16x2(Vec<[i16; 2]>),
Snorm16x4(Vec<[i16; 4]>),
Float16(Vec<f16>),
Float16x2(Vec<[f16; 2]>),
Float16x4(Vec<[f16; 4]>),
Float32(Vec<f32>),
Float32x2(Vec<[f32; 2]>),
Float32x3(Vec<[f32; 3]>),
Float32x4(Vec<[f32; 4]>),
Uint32(Vec<u32>),
Uint32x2(Vec<[u32; 2]>),
Uint32x3(Vec<[u32; 3]>),
Uint32x4(Vec<[u32; 4]>),
Sint32(Vec<i32>),
Sint32x2(Vec<[i32; 2]>),
Sint32x3(Vec<[i32; 3]>),
Sint32x4(Vec<[i32; 4]>),
Float64(Vec<f64>),
Float64x2(Vec<[f64; 2]>),
Float64x3(Vec<[f64; 3]>),
Float64x4(Vec<[f64; 4]>),
Unorm10_10_10_2(Vec<u32>),
Unorm8x4Bgra(Vec<[u8; 4]>),
}Expand description
Contains an array where each entry describes a property of a single vertex.
Matches the VertexFormats.
Variants
Uint8(Vec<u8>)
One unsigned byte (u8). u32 in shaders.
Uint8x2(Vec<[u8; 2]>)
Two unsigned bytes (u8). vec2<u32> in shaders.
Uint8x4(Vec<[u8; 4]>)
Four unsigned bytes (u8). vec4<u32> in shaders.
Sint8(Vec<i8>)
One signed byte (i8). i32 in shaders.
Sint8x2(Vec<[i8; 2]>)
Two signed bytes (i8). vec2<i32> in shaders.
Sint8x4(Vec<[i8; 4]>)
Four signed bytes (i8). vec4<i32> in shaders.
Unorm8(Vec<u8>)
One unsigned byte (u8). [0, 255] converted to float [0, 1] f32 in shaders.
Unorm8x2(Vec<[u8; 2]>)
Two unsigned bytes (u8). [0, 255] converted to float [0, 1] vec2<f32> in shaders.
Unorm8x4(Vec<[u8; 4]>)
Four unsigned bytes (u8). [0, 255] converted to float [0, 1] vec4<f32> in shaders.
Snorm8(Vec<i8>)
One signed byte (i8). [−127, 127] converted to float [−1, 1] f32 in shaders.
Snorm8x2(Vec<[i8; 2]>)
Two signed bytes (i8). [−127, 127] converted to float [−1, 1] vec2<f32> in shaders.
Snorm8x4(Vec<[i8; 4]>)
Four signed bytes (i8). [−127, 127] converted to float [−1, 1] vec4<f32> in shaders.
Uint16(Vec<u16>)
One unsigned short (u16). u32 in shaders.
Uint16x2(Vec<[u16; 2]>)
Two unsigned shorts (u16). vec2<u32> in shaders.
Uint16x4(Vec<[u16; 4]>)
Four unsigned shorts (u16). vec4<u32> in shaders.
Sint16(Vec<i16>)
One signed short (i16). i32 in shaders.
Sint16x2(Vec<[i16; 2]>)
Two signed shorts (i16). vec2<i32> in shaders.
Sint16x4(Vec<[i16; 4]>)
Four signed shorts (i16). vec4<i32> in shaders.
Unorm16(Vec<u16>)
One unsigned short (u16). [0, 65535] converted to float [0, 1] f32 in shaders.
Unorm16x2(Vec<[u16; 2]>)
Two unsigned shorts (u16). [0, 65535] converted to float [0, 1] vec2<f32> in shaders.
Unorm16x4(Vec<[u16; 4]>)
Four unsigned shorts (u16). [0, 65535] converted to float [0, 1] vec4<f32> in shaders.
Snorm16(Vec<i16>)
One signed short (i16). [−32767, 32767] converted to float [−1, 1] f32 in shaders.
Snorm16x2(Vec<[i16; 2]>)
Two signed shorts (i16). [−32767, 32767] converted to float [−1, 1] vec2<f32> in shaders.
Snorm16x4(Vec<[i16; 4]>)
Four signed shorts (i16). [−32767, 32767] converted to float [−1, 1] vec4<f32> in shaders.
Float16(Vec<f16>)
One half-precision float (no Rust equiv). f32 in shaders.
Float16x2(Vec<[f16; 2]>)
Two half-precision floats (no Rust equiv). vec2<f32> in shaders.
Float16x4(Vec<[f16; 4]>)
Four half-precision floats (no Rust equiv). vec4<f32> in shaders.
Float32(Vec<f32>)
One single-precision float (f32). f32 in shaders.
Float32x2(Vec<[f32; 2]>)
Two single-precision floats (f32). vec2<f32> in shaders.
Float32x3(Vec<[f32; 3]>)
Three single-precision floats (f32). vec3<f32> in shaders.
Float32x4(Vec<[f32; 4]>)
Four single-precision floats (f32). vec4<f32> in shaders.
Uint32(Vec<u32>)
One unsigned int (u32). u32 in shaders.
Uint32x2(Vec<[u32; 2]>)
Two unsigned ints (u32). vec2<u32> in shaders.
Uint32x3(Vec<[u32; 3]>)
Three unsigned ints (u32). vec3<u32> in shaders.
Uint32x4(Vec<[u32; 4]>)
Four unsigned ints (u32). vec4<u32> in shaders.
Sint32(Vec<i32>)
One signed int (i32). i32 in shaders.
Sint32x2(Vec<[i32; 2]>)
Two signed ints (i32). vec2<i32> in shaders.
Sint32x3(Vec<[i32; 3]>)
Three signed ints (i32). vec3<i32> in shaders.
Sint32x4(Vec<[i32; 4]>)
Four signed ints (i32). vec4<i32> in shaders.
Float64(Vec<f64>)
One double-precision float (f64). f32 in shaders. Requires wgpu_types::Features::VERTEX_ATTRIBUTE_64BIT.
Float64x2(Vec<[f64; 2]>)
Two double-precision floats (f64). vec2<f32> in shaders. Requires wgpu_types::Features::VERTEX_ATTRIBUTE_64BIT.
Float64x3(Vec<[f64; 3]>)
Three double-precision floats (f64). vec3<f32> in shaders. Requires wgpu_types::Features::VERTEX_ATTRIBUTE_64BIT.
Float64x4(Vec<[f64; 4]>)
Four double-precision floats (f64). vec4<f32> in shaders. Requires wgpu_types::Features::VERTEX_ATTRIBUTE_64BIT.
Unorm10_10_10_2(Vec<u32>)
Three unsigned 10-bit integers and one 2-bit integer, packed into a 32-bit integer (u32). [0, 1023] and [0, 3] converted to float [0, 1] vec4<f32> in shaders.
Unorm8x4Bgra(Vec<[u8; 4]>)
Four unsigned 8-bit integers (u8) in BGRA. [0, 255] converted to float [0, 1] vec4<f32> RGBA in shaders.
Implementations
Sourceimpl VertexAttributeValues
impl VertexAttributeValues
pub fn enum_variant_index(&self) -> usize
pub fn enum_variant_name(&self) -> &'static str
Sourceimpl VertexAttributeValues
impl VertexAttributeValues
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of vertices in this VertexAttributeValues. For a single
mesh, all of the VertexAttributeValues must have the same length.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if there are no vertices in this VertexAttributeValues.
Sourcepub fn as_float3(&self) -> Option<&[[f32; 3]]>
pub fn as_float3(&self) -> Option<&[[f32; 3]]>
Returns the values as float triples if possible.
Sourcepub fn get_bytes(&self) -> &[u8] ⓘ
pub fn get_bytes(&self) -> &[u8] ⓘ
Flattens the VertexAttributeValues into a sequence of bytes. This is
useful for serialization and sending to the GPU.