pub struct CircularSectorMeshBuilder {
pub sector: CircularSector,
pub resolution: u32,
pub uv_mode: CircularMeshUvMode,
}Expand description
A builder used for creating a Mesh with a CircularSector shape.
The resulting mesh will have a UV-map such that the center of the circle is at the center of the texture.
Fields
sector: CircularSectorThe sector shape.
resolution: u32The number of vertices used for the arc portion of the sector mesh.
The default is 32.
uv_mode: CircularMeshUvModeThe UV mapping mode
Implementations
Sourceimpl CircularSectorMeshBuilder
impl CircularSectorMeshBuilder
Sourcepub fn new(sector: CircularSector) -> CircularSectorMeshBuilder
pub fn new(sector: CircularSector) -> CircularSectorMeshBuilder
Creates a new CircularSectorMeshBuilder from a given sector
Sourcepub const fn resolution(self, resolution: u32) -> CircularSectorMeshBuilder
pub const fn resolution(self, resolution: u32) -> CircularSectorMeshBuilder
Sets the number of vertices used for the sector mesh.
Sourcepub const fn uv_mode(
self,
uv_mode: CircularMeshUvMode,
) -> CircularSectorMeshBuilder
pub const fn uv_mode( self, uv_mode: CircularMeshUvMode, ) -> CircularSectorMeshBuilder
Sets the uv mode used for the sector mesh